// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#ifndef ECM_QLOGGINGCATEGORY_FFMPEGTHUMBS_LOG_FFMPEGTHUMBS_DEBUG_H
#define ECM_QLOGGINGCATEGORY_FFMPEGTHUMBS_LOG_FFMPEGTHUMBS_DEBUG_H

#include <QLoggingCategory>

Q_DECLARE_LOGGING_CATEGORY(ffmpegthumbs_LOG)


#endif
