// This file is generated by kconfig_compiler_kf6 from ffmpegthumbnailersettings5.kcfg.
// All changes you do to this file will be lost.
#ifndef FFMPEGTHUMBNAILERSETTINGS_H
#define FFMPEGTHUMBNAILERSETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class FFMpegThumbnailerSettings : public KConfigSkeleton
{
  public:

    static FFMpegThumbnailerSettings *self();
    ~FFMpegThumbnailerSettings() override;

    /**
      Set Embed filmstrip effect
    */
    static
    void setFilmstrip( bool v )
    {
      if (!self()->isFilmstripImmutable())
        self()->mFilmstrip = v;
    }

    /**
      Get Embed filmstrip effect
    */
    static
    bool filmstrip()
    {
      return self()->mFilmstrip;
    }

    /**
      Is Embed filmstrip effect Immutable
    */
    static
    bool isFilmstripImmutable()
    {
      return self()->isImmutable( QStringLiteral( "filmstrip" ) );
    }

    /**
      Set Sequence seek percentages
    */
    static
    void setSequenceSeekPercentages( const QList<int> & v )
    {
      if (!self()->isSequenceSeekPercentagesImmutable())
        self()->mSequenceSeekPercentages = v;
    }

    /**
      Get Sequence seek percentages
    */
    static
    QList<int> sequenceSeekPercentages()
    {
      return self()->mSequenceSeekPercentages;
    }

    /**
      Is Sequence seek percentages Immutable
    */
    static
    bool isSequenceSeekPercentagesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "sequenceSeekPercentages" ) );
    }

    /**
      Set Cache size (KiB)
    */
    static
    void setCacheSize( uint v )
    {
      if (!self()->isCacheSizeImmutable())
        self()->mCacheSize = v;
    }

    /**
      Get Cache size (KiB)
    */
    static
    uint cacheSize()
    {
      return self()->mCacheSize;
    }

    /**
      Is Cache size (KiB) Immutable
    */
    static
    bool isCacheSizeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "cacheSize" ) );
    }

  protected:
    FFMpegThumbnailerSettings();
    friend class FFMpegThumbnailerSettingsHelper;


    // General
    bool mFilmstrip;
    QList<int> mSequenceSeekPercentages;
    uint mCacheSize;
};

#endif

