// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "ffmpegthumbs_debug.h"


Q_LOGGING_CATEGORY(ffmpegthumbs_LOG, "org.kde.kdemultimedia.ffmpegthumbs", QtCriticalMsg)

